@@ -58,12 +58,18 @@ class DocumentMeta(type):
             raise DocumentException("config_extra_fields must be one of: 'error', 'ignore'")
         
         # 1. Set up links between fields and the document class
+        new_id = False
         for name, value in class_dict.iteritems():
             if not isinstance(value, Field):
                 continue
+            if value.is_id and name != 'mongo_id':
+                new_id = True
             value._set_name(name)
             value._set_parent(new_class)
         
+        if new_id:
+            new_class.mongo_id = None
+        
         # 2. create a dict of fields to set on the object
         new_class._fields = {}
         for name in dir(new_class):
@@ -150,6 +156,8 @@ class Document(object):
                     self.__extra_fields[k] = kwargs[k]
                 else:
                     raise ExtraValueException(k)
+
+        self.__extra_fields_orig = dict(self.__extra_fields)
     
     def get_dirty_ops(self, with_required=False):
         ''' Returns a dict with the update operations necessary to make the 
@@ -163,6 +171,8 @@ class Document(object):
         '''
         update_expression = {}
         for name, field in self.get_fields().iteritems():
+            if field.db_field == '_id':
+                continue
             dirty_ops = field.dirty_ops(self)
             if not dirty_ops and with_required and field.required:
                 dirty_ops = field.update_ops(self)
@@ -173,6 +183,27 @@ class Document(object):
                 update_expression.setdefault(op, {})
                 for key, value in values.iteritems():
                     update_expression[op][key] = value
+
+        if self.config_extra_fields == 'ignore':
+            old_extrakeys = set(self.__extra_fields_orig.keys())
+            cur_extrakeys = set(self.__extra_fields.keys())
+
+            new_extrakeys = cur_extrakeys - old_extrakeys
+            rem_extrakeys = old_extrakeys - cur_extrakeys
+            same_extrakeys = cur_extrakeys & old_extrakeys
+
+            update_expression.setdefault('$unset', {})
+            for key in rem_extrakeys:
+                update_expression['$unset'][key] = True
+
+            update_expression.setdefault('$set', {})
+            for key in new_extrakeys:
+                update_expression['$set'][key] = self.__extra_fields[key]
+
+            for key in same_extrakeys:
+                if self.__extra_fields[key] != self.__extra_fields_orig[key]:
+                    update_expression['$set'][key] = self.__extra_fields[key]
+
         return update_expression
     
     def get_extra_fields(self):
@@ -263,11 +294,10 @@ class Document(object):
                 continue
             try:
                 value = getattr(self, name)
+                res[field.db_field] = field.wrap(value)
             except AttributeError:
                 if field.required:
                     raise MissingValueException(name)
-                continue
-            res[field.db_field] = field.wrap(value)
         return res
     
     @classmethod
@@ -390,7 +420,8 @@ class DocumentField(Field):
             document = getattr(instance, self._name)
         except AttributeError:
             return {}
-        if len(document._dirty) == 0:
+        if len(document._dirty) == 0 and \
+           self.__type.config_extra_fields != 'ignore':
             return {}
         
         ops = document.get_dirty_ops()
