@@ -25,8 +25,8 @@ from pymongo import ASCENDING, DESCENDING
 from copy import copy, deepcopy
 
 from mongoalchemy.fields import BadValueException
-from mongoalchemy.query_expression import QueryExpression, BadQueryException
-from mongoalchemy.update_expression import UpdateExpression
+from mongoalchemy.query_expression import QueryExpression, BadQueryException, flatten
+from mongoalchemy.update_expression import UpdateExpression, FindAndModifyExpression
 
 class BadResultException(Exception):
     ''' Only raised right now when .one() finds more than one object '''
@@ -52,6 +52,7 @@ class Query(object):
         self.hints = []
         self._limit = None
         self._skip = None
+        self._raw_output = False
     
     def __iter__(self):
         return self.__get_query_result()
@@ -66,24 +67,15 @@ class Query(object):
     
     @property
     def query(self):
-        def flatten(obj):
-            if not isinstance(obj, dict):
-                return obj
-            ret = {}
-            for k, v in obj.iteritems():
-                if not isinstance(k, basestring):
-                    k = str(k)
-                if isinstance(v, dict):
-                    v = flatten(v)
-                if isinstance(v, list):
-                    v = [flatten(x) for x in v]
-                ret[k] = v
-            return ret
         return flatten(self.__query)
     
     def __get_query_result(self):
         return self.session.execute_query(self)
     
+    def raw_output(self):
+        self._raw_output = True
+        return self
+    
     def get_fields(self):
         return self._fields
     
@@ -121,6 +113,7 @@ class Query(object):
         qclone._hints = deepcopy(self.hints)
         qclone._limit = deepcopy(self._limit)
         qclone._skip = deepcopy(self._skip)
+        qclone._raw_output = deepcopy(self._raw_output)
         return qclone
     
     def one(self):
@@ -329,7 +322,17 @@ class Query(object):
         qfield = self.resolve_name(qfield)
         self.filter(QueryExpression({ qfield : { '$nin' : [qfield.wrap_value(value) for value in values]}}))
         return self
-
+    
+    def find_and_modify(self, new=False, remove=False):
+        ''' The mongo "find and modify" command.  Behaves like an update expression
+            in that "execute" must be called to do the update and return the 
+            results.
+            
+            :param new: Whether to return the new object or old (default: False)
+            :param remove: Whether to remove the object before returning it
+        '''
+        return FindAndModifyExpression(self, new=new, remove=remove)
+        
     
     def set(self, *args, **kwargs):
         ''' Refer to: :func:`~mongoalchemy.update_expression.UpdateExpression.set`'''
@@ -373,24 +376,30 @@ class Query(object):
 
 
 class QueryResult(object):
-    def __init__(self, cursor, type, fields=None):
+    def __init__(self, cursor, type, raw_output=False, fields=None):
         self.cursor = cursor
         self.type = type
         self.fields = fields
+        self.raw_output = raw_output
     
     def next(self):
         value = self.cursor.next()
-        return self.type.unwrap(value, fields=self.fields)
+        if not self.raw_output:
+            value = self.type.unwrap(value, fields=self.fields)
+        return value
     
     def __getitem__(self, index):
         value = self.cursor.__getitem__(index)
-        return self.type.unwrap(value)
+        if not self.raw_output:
+            value = self.type.unwrap(value)
+        return value
     
     def rewind(self):
         return self.cursor.rewind()
     
     def clone(self):
-        return QueryResult(self.cursor.clone(), self.type, fields=self.fields)
+        return QueryResult(self.cursor.clone(), self.type, 
+            raw_output=self.raw_output, fields=self.fields)
     
     def __iter__(self):
         return self
