@@ -222,7 +222,7 @@ class Session(object):
 
         return self.db[remove.type.get_collection_name()].remove(remove.query, safe=safe)
     
-    def execute_update(self, update):
+    def execute_update(self, update, safe=False):
         ''' Execute an update expression.  Should generally only be called implicitly.
         '''
         
@@ -231,7 +231,13 @@ class Session(object):
         collection = self.db[update.query.type.get_collection_name()]
         for index in update.query.type.get_indexes():
             index.ensure(collection)
-        collection.update(update.query.query, update.update_data, upsert=update.get_upsert(), multi=update.get_multi())
+        kwargs = dict(
+            upsert=update.get_upsert(), 
+            multi=update.get_multi(),
+            safe=safe,
+        )
+        print kwargs
+        collection.update(update.query.query, update.update_data, **kwargs)
     
     def execute_find_and_modify(self, fm_exp):
         self.flush()
@@ -257,6 +263,10 @@ class Session(object):
             kwargs['remove'] = fm_exp.get_remove()
         
         value = collection.find_and_modify(**kwargs)        
+        
+        if value is None:
+            return None
+        
         if kwargs['upsert'] and not kwargs.get('new') and len(value) == 0:
             return value
         
@@ -284,7 +294,11 @@ class Session(object):
         if safe is None:
             safe = self.safe
         for index, item in enumerate(self.queue):
-            item.commit(self.db, safe=safe)
+            try:
+                item.commit(self.db, safe=safe)
+            except:
+                self.clear()
+                raise
         self.clear()
             
     
