@@ -24,4 +24,12 @@ def classproperty(fun):
     class Descriptor(property):
         def __get__(self, instance, owner):
             return fun(owner)
-    return Descriptor()
\ No newline at end of file
+    return Descriptor()
+
+class UNSET(object): 
+    def __repr__(self):
+        return 'UNSET'
+    def __eq__(self, other):
+        return other.__class__ == self.__class__
+UNSET = UNSET()
+
