@@ -34,6 +34,15 @@ def test_allow_none():
     assert IntField(allow_none=True).wrap(None) == None
     assert IntField(allow_none=True).unwrap(None) == None
 
+def test_id_attr():
+    assert IntField().is_id == False
+    assert IntField(db_field='_id').is_id == True
+    assert IntField(_id=True).is_id == True
+
+@raises(InvalidConfigException)
+def test_bad_id_attr():
+    IntField(db_field='foo', _id=True)
+
 @raises(InvalidConfigException)
 def test_bad_on_update_value():
     IntField(on_update='set')
@@ -227,6 +236,6 @@ def binary_wrong_type_test_unwrap():
 
 def binary_value_test():
     s = BinaryField()
-    assert s.wrap(Binary('foo')) == Binary('foo')
-    assert s.wrap('foo') == Binary('foo')
-    assert s.unwrap(Binary('foo')) == Binary('foo')
+    assert s.wrap(Binary(bytes('foo'.encode('ascii')))) == Binary(bytes('foo'.encode('ascii')))
+    assert s.wrap(bytes('foo'.encode('ascii'))) == Binary(bytes('foo'.encode('ascii')))
+    assert s.unwrap(Binary(bytes('foo'.encode('ascii')))) == Binary(bytes('foo'.encode('ascii')))
